:mod:`langacore.kit.django.cache`
=================================

.. automodule:: langacore.kit.django.cache

Functions
----------

.. autofunction:: get

.. autofunction:: set

.. autofunction:: delete 
